from .is_option_list_item import is_option_list_item

def collect_option_list_item(lines, index, interspace):
    output = []
    leading_space = lines[index].replace(lines[index].lstrip(), '')
    
    option = lines[index].lstrip().split('  ')[0]
    rest_of_text = lines[index].lstrip()[len(option)::]
    
    output.append(leading_space + option + interspace + rest_of_text)
    index += 1
    
    while index < len(lines):
        if (not is_option_list_item(lines, index) and
            not lines[index] == ''
        ):
            output.append(lines[index].lstrip())
        else:
            return ' '.join(output), index
    
    return '\n'.join(output), index
    
    



from .reflow_paragraph import reflow_paragraph
from .tools import space_fill

def reflow_option_list_item(text, space):

    leading_space = text.replace(text.lstrip(), '')
    option = text.lstrip().split('  ')[0]
    rest_of_text = text.lstrip()[len(option)::]
    interspace = rest_of_text.replace(rest_of_text.lstrip(), '')
    
    lspace = leading_space + space_fill(len(option), ' ') + interspace
    
    paragraph = reflow_paragraph(rest_of_text.lstrip(), space, lspace)
    paragraph = paragraph.lstrip()
    
    return leading_space + option + interspace + paragraph



def other_colon_present(words):
    for word in words:
        if word.endswith(':') and not word.endswith('\\:'):
            return True
    return False

def is_field(lines, index):
    words = lines[index].lstrip().split(' ')

    if not words[0].endswith(':'):
        if not words[0].startswith(':'):
            return False
        
        if not other_colon_present(words):
            return False
    
    return True
    
    '''
    leading_space = lines[index].replace(lines[index].lstrip(), '')
    
    if index > 0 and not lines[index - 1] == '':
        former_leading_space = lines[index - 1].replace(
            lines[index - 1].lstrip(), '')
            
        if not is_field(lines, index - 1):
            if len(leading_space) <= len(former_leading_space):
                return False
            else:
                return True
        else:
            return True
    else:
        return True
    '''



def is_option_list_item(lines, index):
    if not lines[index].startswith('-') and not lines[index].startswith('/'):
        return False
    
    if not '  ' in lines[index]:
        return False
        
    return True
